==> onos-yang-runtime-2.2.0-sources.jar: org/onosproject/yang/gen/v1/ietfl3vpnsvc/rev20160730/ietfl3vpnsvc/siterouting/DefaultRoutingProtocols.java <==
/*
 * Copyright 2017-present Open Networking Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.onosproject.yang.gen.v1.ietfl3vpnsvc.rev20160730.ietfl3vpnsvc.siterouting;

import java.util.ArrayList;
import java.util.List;
import java.util.Objects;
import java.util.StringJoiner;
import org.onosproject.yang.gen.v1.ietfl3vpnsvc.rev20160730.ietfl3vpnsvc.siterouting.routingprotocols.RoutingProtocol;
import org.onosproject.yang.model.InnerModelObject;

/**
 * Represents the implementation of routingProtocols.
 *
 * <p>
 * valueLeafFlags identify the leafs whose value are explicitly set
 * Applicable in protocol edit and query operation.
 * </p>
 */
public class DefaultRoutingProtocols extends InnerModelObject implements RoutingProtocols {
    protected List<RoutingProtocol> routingProtocol;

    @Override
    public List<RoutingProtocol> routingProtocol() {
        return routingProtocol;
    }

    @Override
    public void routingProtocol(List<RoutingProtocol> routingProtocol) {
        this.routingProtocol = routingProtocol;
    }

    @Override
    public void addToRoutingProtocol(RoutingProtocol addTo) {
        if (routingProtocol == null) {
            routingProtocol = new ArrayList<>();
        }
        routingProtocol.add(addTo);
    }


    @Override
    public int hashCode() {
        return Objects.hash(routingProtocol);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj instanceof DefaultRoutingProtocols) {
            DefaultRoutingProtocols other = (DefaultRoutingProtocols) obj;
            return
                Objects.equals(routingProtocol, other.routingProtocol);
        }
        return false;
    }

    @Override
    public String toString() {
        return new StringJoiner(", ", getClass().getSimpleName() +"{", "}")
            .add("routingProtocol=" + routingProtocol)
            .toString();
    }


    /**
     * Creates an instance of defaultRoutingProtocols.
     */
    public DefaultRoutingProtocols() {
    }

}

==> onos-yang-runtime-2.3.1-sources.jar: org/onosproject/yang/gen/v1/ietfl3vpnsvc/rev20160730/ietfl3vpnsvc/siterouting/DefaultRoutingProtocols.java <==
/*
 * Copyright 2017-present Open Networking Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.onosproject.yang.gen.v1.ietfl3vpnsvc.rev20160730.ietfl3vpnsvc.siterouting;

import java.util.ArrayList;
import java.util.List;
import java.util.Objects;
import java.util.StringJoiner;
import org.onosproject.yang.gen.v1.ietfl3vpnsvc.rev20160730.ietfl3vpnsvc.siterouting.routingprotocols.RoutingProtocol;
import org.onosproject.yang.model.InnerModelObject;

/**
 * Represents the implementation of routingProtocols.
 *
 * <p>
 * valueLeafFlags identify the leafs whose value are explicitly set
 * Applicable in protocol edit and query operation.
 * </p>
 */
public class DefaultRoutingProtocols extends InnerModelObject implements RoutingProtocols {
    protected List<RoutingProtocol> routingProtocol;

    @Override
    public List<RoutingProtocol> routingProtocol() {
        return routingProtocol;
    }

    @Override
    public void routingProtocol(List<RoutingProtocol> routingProtocol) {
        this.routingProtocol = routingProtocol;
    }

    @Override
    public void addToRoutingProtocol(RoutingProtocol addTo) {
        if (routingProtocol == null) {
            routingProtocol = new ArrayList<>();
        }
        routingProtocol.add(addTo);
    }


    @Override
    public int hashCode() {
        return Objects.hash(routingProtocol);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj instanceof DefaultRoutingProtocols) {
            DefaultRoutingProtocols other = (DefaultRoutingProtocols) obj;
            return
                Objects.deepEquals(routingProtocol, other.routingProtocol);
        }
        return false;
    }

    @Override
    public String toString() {
        return new StringJoiner(", ", getClass().getSimpleName() +"{", "}")
            .add("routingProtocol=" + routingProtocol)
            .toString();
    }


    /**
     * Creates an instance of defaultRoutingProtocols.
     */
    public DefaultRoutingProtocols() {
    }

}
